@@ -32,6 +32,7 @@ class ClassificationMetric(Evaluator):
         self.set_keyword_arguments(kwargs)
         self.binary = True
         self.representor = "number"     # "number" or "string"
+        self.le = None  # LabelEncoder
 
     def get_processed_data(self, y_true=None, y_pred=None, decimal=None):
         """
@@ -49,15 +50,12 @@ class ClassificationMetric(Evaluator):
         """
         decimal = self.decimal if decimal is None else decimal
         if (y_true is not None) and (y_pred is not None):
-            y_true, y_pred = format_classification_data_type(y_true, y_pred)
             y_true, y_pred, binary, representor = format_classification_data(y_true, y_pred)
         else:
             if (self.y_true is not None) and (self.y_pred is not None):
-                y_true, y_pred = format_classification_data_type(self.y_true, self.y_pred)
-                y_true, y_pred, binary, representor = format_classification_data(y_true, y_pred)
+                y_true, y_pred, binary, representor = format_classification_data(self.y_true, self.y_pred)
             else:
-                print("Permetrics Error! You need to pass y_true and y_pred to object creation or function called.")
-                exit(0)
+                raise ValueError("y_true or y_pred is None. You need to pass y_true and y_pred to object creation or function called.")
         return y_true, y_pred, binary, representor, decimal
 
     def confusion_matrix(self, y_true=None, y_pred=None, labels=None, normalize=None):
@@ -76,10 +74,10 @@ class ClassificationMetric(Evaluator):
             imap_count (dict): a map between label and number of true label in y_true
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal=None)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize)
         return matrix, imap, imap_count
 
-    def precision_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def precision_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate precision score for multiple classification problem
 
@@ -87,7 +85,7 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
                 If None, the scores for each class are returned. Otherwise, this determines the type of averaging performed on the data:
 
                 ``'micro'``:
@@ -103,7 +101,7 @@ class ClassificationMetric(Evaluator):
             precision (float, dict): the precision score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_precision = np.array([item["precision"] for item in metrics.values()])
@@ -121,7 +119,7 @@ class ClassificationMetric(Evaluator):
             precision = dict([(label, np.round(item["precision"], decimal)) for label, item in metrics.items()])
         return precision if type(precision) == dict else np.round(precision, decimal)
 
-    def negative_predictive_value(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def negative_predictive_value(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate negative predictive value for multiple classification problem
 
@@ -129,14 +127,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             npv (float, dict): the negative predictive value
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_npv = np.array([item["negative_predictive_value"] for item in metrics.values()])
@@ -154,7 +152,7 @@ class ClassificationMetric(Evaluator):
             npv = dict([(label, np.round(item["negative_predictive_value"], decimal)) for label, item in metrics.items()])
         return npv if type(npv) == dict else np.round(npv, decimal)
 
-    def specificity_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def specificity_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate specificity score for multiple classification problem
 
@@ -162,14 +160,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             ss (float, dict): the specificity score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_ss = np.array([item["specificity"] for item in metrics.values()])
@@ -187,7 +185,7 @@ class ClassificationMetric(Evaluator):
             ss = dict([(label, np.round(item["specificity"], decimal)) for label, item in metrics.items()])
         return ss if type(ss) == dict else np.round(ss, decimal)
 
-    def recall_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def recall_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate recall score for multiple classification problem
 
@@ -195,14 +193,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             recall (float, dict): the recall score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_recall = np.array([item["recall"] for item in metrics.values()])
@@ -220,7 +218,7 @@ class ClassificationMetric(Evaluator):
             recall = dict([(label, np.round(item["recall"], decimal)) for label, item in metrics.items()])
         return recall if type(recall) == dict else np.round(recall, decimal)
 
-    def accuracy_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def accuracy_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate accuracy score for multiple classification problem
 
@@ -228,14 +226,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             accuracy (float, dict): the accuracy score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_accuracy = np.array([item["accuracy"] for item in metrics.values()])
@@ -252,7 +250,7 @@ class ClassificationMetric(Evaluator):
             accuracy = dict([(label, np.round(item["precision"], decimal)) for label, item in metrics.items()])
         return accuracy if type(accuracy) == dict else np.round(accuracy, decimal)
 
-    def f1_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def f1_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate f1 score for multiple classification problem
 
@@ -260,14 +258,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             f1 (float, dict): the f1 score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_f1 = np.array([item["f1"] for item in metrics.values()])
@@ -287,7 +285,7 @@ class ClassificationMetric(Evaluator):
             f1 = dict([(label, item["f1"]) for label, item in metrics.items()])
         return f1 if type(f1) == dict else np.round(f1, decimal)
 
-    def f2_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def f2_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate f2 score for multiple classification problem
 
@@ -295,14 +293,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             f2 (float, dict): the f2 score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_f2 = np.array([item["f1"] for item in metrics.values()])
@@ -322,7 +320,7 @@ class ClassificationMetric(Evaluator):
             f2 = dict([(label, item["f2"]) for label, item in metrics.items()])
         return f2 if type(f2) == dict else np.round(f2, decimal)
 
-    def fbeta_score(self, y_true=None, y_pred=None, beta=1.0, labels=None, average=None, decimal=None):
+    def fbeta_score(self, y_true=None, y_pred=None, beta=1.0, labels=None, average="macro", decimal=None):
         """
         The beta parameter determines the weight of recall in the combined score.
         beta < 1 lends more weight to precision, while beta > 1 favors recall
@@ -333,14 +331,14 @@ class ClassificationMetric(Evaluator):
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             beta (float): the weight of recall in the combined score, default = 1.0
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             fbeta (float, dict): the fbeta score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count, beta=beta)
 
         list_fbeta = np.array([item["f1"] for item in metrics.values()])
@@ -360,20 +358,20 @@ class ClassificationMetric(Evaluator):
             fbeta = dict([(label, item["fbeta"]) for label, item in metrics.items()])
         return fbeta if type(fbeta) == dict else np.round(fbeta, decimal)
 
-    def matthews_correlation_coefficient(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def matthews_correlation_coefficient(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Args:
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
-            beta (float): the weight of recall in the combined score, default = 1.0
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             mcc (float, dict): the Matthews correlation coefficient
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_mcc = np.array([item["mcc"] for item in metrics.values()])
@@ -382,7 +380,7 @@ class ClassificationMetric(Evaluator):
         if average == "micro":
             tp = tn = np.sum(np.diag(matrix))
             fp = fn = np.sum(matrix) - tp
-            mcc = (tp * tn - fp * fn) / ((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn))
+            mcc = (tp * tn - fp * fn) / np.sqrt(((tp + fp) * (tp + fn) * (tn + fp) * (tn + fn)))
         elif average == "macro":
             mcc = np.mean(list_mcc)
         elif average == "weighted":
@@ -391,7 +389,7 @@ class ClassificationMetric(Evaluator):
             mcc = dict([(label, item["mcc"]) for label, item in metrics.items()])
         return mcc if type(mcc) == dict else np.round(mcc, decimal)
 
-    def hamming_loss(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def hamming_loss(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate hamming loss for multiple classification problem
 
@@ -399,14 +397,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             hl (float, dict): the hamming loss
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_accuracy = np.array([item["accuracy"] for item in metrics.values()])
@@ -423,7 +421,7 @@ class ClassificationMetric(Evaluator):
             hl = dict([(label, np.round(item["hamming_loss"], decimal)) for label, item in metrics.items()])
         return hl if type(hl) == dict else np.round(hl, decimal)
 
-    def lift_score(self, y_true=None, y_pred=None, labels=None, average=None, decimal=None):
+    def lift_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
         """
         Generate lift score for multiple classification problem
 
@@ -431,14 +429,14 @@ class ClassificationMetric(Evaluator):
             y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
             y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
             labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
-            average (str, None): {'micro', 'macro', 'weighted'} or None, default=None, others=None
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
             decimal (int): The number of fractional parts after the decimal point
 
         Returns:
             ls (float, dict): the lift score
         """
         y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
-        matrix, imap, imap_count = confusion_matrix(y_true, y_pred, labels, normalize=None)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
         metrics = calculate_single_label_metric(matrix, imap, imap_count)
 
         list_ls = np.array([item["lift_score"] for item in metrics.values()])
@@ -456,6 +454,184 @@ class ClassificationMetric(Evaluator):
             ls = dict([(label, np.round(item["lift_score"], decimal)) for label, item in metrics.items()])
         return ls if type(ls) == dict else np.round(ls, decimal)
 
+    def cohen_kappa_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
+        """
+        Generate Cohen Kappa score for multiple classification problem
+
+        Args:
+            y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
+            y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
+            labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
+            decimal (int): The number of fractional parts after the decimal point
+
+        Returns:
+            cks (float, dict): the Cohen Kappa score
+        """
+        y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
+        metrics = calculate_single_label_metric(matrix, imap, imap_count)
+
+        list_kp = np.array([item["kappa_score"] for item in metrics.values()])
+        list_weights = np.array([item["n_true"] for item in metrics.values()])
+
+        if average == 'weighted':
+            kappa = np.dot(list_weights, list_kp) / np.sum(list_weights)
+        elif average == 'macro':
+            kappa = np.mean(list_kp)
+        elif average == 'micro':
+            kappa = np.average(list_kp)
+        else:
+            kappa = dict([(label, np.round(item["kappa_score"], decimal)) for label, item in metrics.items()])
+        return kappa if type(kappa) == dict else np.round(kappa, decimal)
+
+    def jaccard_similarity_index(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
+        """
+        Generate Jaccard similarity index for multiple classification problem
+
+        Args:
+            y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
+            y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
+            labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
+            decimal (int): The number of fractional parts after the decimal point
+
+        Returns:
+            jsi (float, dict): the Jaccard similarity index
+        """
+        y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
+        metrics = calculate_single_label_metric(matrix, imap, imap_count)
+
+        list_js = np.array([item["jaccard_similarities"] for item in metrics.values()])
+        list_weights = np.array([item["n_true"] for item in metrics.values()])
+
+        if average == "micro":
+            tp = tn = np.sum(np.diag(matrix))
+            fp = fn = np.sum(matrix) - tp
+            js = tp / (tp + fp + fn)
+        elif average == "macro":
+            js = np.mean(list_js)
+        elif average == "weighted":
+            js = np.dot(list_weights, list_js) / np.sum(list_weights)
+        else:
+            js = dict([(label, np.round(item["jaccard_similarities"], decimal)) for label, item in metrics.items()])
+        return js if type(js) == dict else np.round(js, decimal)
+
+    def g_mean_score(self, y_true=None, y_pred=None, labels=None, average="macro", decimal=None):
+        """
+        Calculates the G-mean score between y_true and y_pred.
+
+        Args:
+            y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
+            y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
+            labels (tuple, list, np.ndarray): List of labels to index the matrix. This may be used to reorder or select a subset of labels.
+            average (str, None): {'micro', 'macro', 'weighted'} or None, default="macro"
+            decimal (int): The number of fractional parts after the decimal point
+
+        Returns:
+            float, dict: The G-mean score.
+        """
+        y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        matrix, imap, imap_count = calculate_confusion_matrix(y_true, y_pred, labels, normalize=None)
+        metrics = calculate_single_label_metric(matrix, imap, imap_count)
+
+        list_gm = np.array([item["g_mean"] for item in metrics.values()])
+        list_weights = np.array([item["n_true"] for item in metrics.values()])
+
+        if average == "micro":
+            tp = tn = np.sum(np.diag(matrix))
+            fp = fn = np.sum(matrix) - tp
+            gm = np.sqrt((tp / (tp + fn)) * (tn / (tn + fp)))
+        elif average == "macro":
+            gm = np.mean(list_gm)
+        elif average == "weighted":
+            gm = np.dot(list_weights, list_gm) / np.sum(list_weights)
+        else:
+            gm = dict([(label, np.round(item["g_mean"], decimal)) for label, item in metrics.items()])
+        return gm if type(gm) == dict else np.round(gm, decimal)
+
+    def gini_index(self, y_true=None, y_pred=None, average="macro", decimal=None):
+        """
+        Calculates the Gini index between y_true and y_pred. Higher is better. Range [0, 1]
+
+        Args:
+            y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
+            y_pred (tuple, list, np.ndarray): a list of integers or strings for y_pred classes
+            average (str, None): {'macro', 'weighted'} or None, default="macro"
+            decimal (int): The number of fractional parts after the decimal point
+
+        Returns:
+            float, dict: The Gini index
+        """
+        y_true, y_pred, binary, representor, decimal = self.get_processed_data(y_true, y_pred, decimal)
+        if binary:
+            return calculate_gini(y_true, y_pred)
+        else:
+            # Compute the number of classes and examples
+            num_classes = len(np.unique(y_true))
+            num_examples = len(y_true)
+            # Initialize arrays to store class weights and Gini indices
+            class_weights = np.zeros(num_classes)
+            class_ginis = np.zeros(num_classes)
+            # Compute the Gini index for each class
+            for i in range(num_classes):
+                # Create a binary array indicating whether the example belongs to the current class
+                y_true_binary = np.where(y_true == i, 1, 0)
+                # Compute the Gini index for the current class using the binary array and predicted scores
+                class_ginis[i] = calculate_gini(y_true_binary, y_pred)
+                # Compute the class weight based on the number of examples
+                class_weights[i] = np.sum(y_true_binary) / num_examples
+
+            if average == "macro":
+                result = np.mean(class_ginis)
+            elif average == "weighted":
+                result = np.dot(class_weights, class_ginis) / np.sum(class_weights)
+            else:
+                result = dict([(idx, np.round(class_ginis[idx], decimal)) for idx in range(num_classes)])
+            return result if type(result) == dict else np.round(result, decimal)
+
+    def roc_auc_score(self, y_true=None, y_score=None, average="macro", decimal=5):
+        """
+        Calculates the ROC-AUC score between y_true and y_score.
+
+        Args:
+            y_true (tuple, list, np.ndarray): a list of integers or strings for known classes
+            y_score (tuple, list, np.ndarray): a list of predicted scores.
+            average (str, None): {'macro', 'weighted'} or None, default="macro"
+            decimal (int): The number of fractional parts after the decimal point
+
+        Returns:
+            float, dict: The AUC score.
+        """
+        y_true, y_score, binary, representor = format_y_score(y_true, y_score)
+        if binary:
+            tpr, fpr, thresholds = calculate_roc_curve(y_true, y_score)
+            # Calculate the area under the curve (AUC) using the trapezoidal rule
+            return np.trapz(tpr, fpr)
+        else:
+            list_weights = calculate_class_weights(y_true, y_pred=None, y_score=y_score)
+            # one-vs-all (rest) approach
+            tpr = dict()
+            fpr = dict()
+            thresholds = dict()
+            auc = []
+            n_classes = len(np.unique(y_true))
+            for i in range(n_classes):
+                y_true_i = np.array([1 if y == i else 0 for y in y_true])
+                y_score_i = y_score[:, i]
+                tpr[i], fpr[i], thresholds[i] = calculate_roc_curve(y_true_i, y_score_i)
+                # Calculate the area under the curve (AUC) using the trapezoidal rule
+                auc.append(np.trapz(tpr[i], fpr[i]))
+            if average == "macro":
+                result = np.mean(auc)
+            elif average == "weighted":
+                result = np.dot(list_weights, auc) / np.sum(list_weights)
+            else:
+                result = dict([(idx, np.round(auc[idx], decimal)) for idx in range(n_classes)])
+            return result if type(result) == dict else np.round(result, decimal)
+
+
     CM = cm = confusion_matrix
     PS = ps = precision_score
     NPV = npv = negative_predictive_value
@@ -468,5 +644,8 @@ class ClassificationMetric(Evaluator):
     MCC = mcc = matthews_correlation_coefficient
     HL = hl = hamming_loss
     LS = ls = lift_score
-
-
+    CKS = cks = cohen_kappa_score
+    JSI = jsi = JSC = jsc = jaccard_similarity_coefficient = jaccard_similarity_index
+    GMS = gms = g_mean_score
+    GINI = gini = gini_index
+    ROC = AUC = RAS = roc = auc = ras = roc_auc_score
